# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AM;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20200904144526;

my $formatters = [
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '[89]0',
                  'national_rule' => '0 $1',
                  'pattern' => '(\\d{3})(\\d{2})(\\d{3})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            2|
            3[12]
          ',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d{3})(\\d{5})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            1|
            47
          ',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d{2})(\\d{6})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '[3-9]',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{6})'
                }
              ];

my $validators = {
                'fixed_line' => '
          (?:
            (?:
              1[0-25]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'geographic' => '
          (?:
            (?:
              1[0-25]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'mobile' => '
          (?:
            33|
            4[1349]|
            55|
            77|
            88|
            9[13-9]
          )\\d{6}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(80[1-4]\\d{5})|(90[016]\\d{5})',
                'toll_free' => '800\\d{5}',
                'voip' => '
          60(?:
            2[78]|
            3[5-9]|
            4[02-9]|
            5[0-46-9]|
            [6-8]\\d|
            90
          )\\d{4}
        '
              };
my %areanames = ();
$areanames{en}->{37410} = "Yerevan\/Jrvezh";
$areanames{en}->{37411} = "Yerevan";
$areanames{en}->{37412} = "Yerevan";
$areanames{en}->{37415} = "Yerevan";
$areanames{en}->{3742220} = "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk";
$areanames{en}->{3742221} = "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk";
$areanames{en}->{3742222} = "Abovyan\,\ Kotayk";
$areanames{en}->{3742223} = "Abovyan\,\ Kotayk";
$areanames{en}->{3742224} = "Abovyan\,\ Kotayk";
$areanames{en}->{3742225} = "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk";
$areanames{en}->{3742226} = "Abovyan\,\ Kotayk";
$areanames{en}->{3742227} = "Garni\/Abovyan\,\ Kotayk";
$areanames{en}->{3742228} = "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk";
$areanames{en}->{37422281} = "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk";
$areanames{en}->{37422290} = "Mayakovsky\,\ Kotayk";
$areanames{en}->{37422291} = "Balahovit\/Kamaris\,\ Kotayk";
$areanames{en}->{37422292} = "Zovk\/Abovyan\,\ Kotayk";
$areanames{en}->{37422293} = "Aramus\,\ Kotayk";
$areanames{en}->{37422294} = "Arzni\,\ Kotayk";
$areanames{en}->{37422295} = "Zovk\/Abovyan\,\ Kotayk";
$areanames{en}->{37422296} = "Ptghni\,\ Kotayk";
$areanames{en}->{37422297} = "Geghashen\,\ Kotayk";
$areanames{en}->{37422298} = "Arinj\,\ Kotayk";
$areanames{en}->{37422299} = "Kotayk";
$areanames{en}->{3742230} = "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk";
$areanames{en}->{3742231} = "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk";
$areanames{en}->{3742232} = "Hrazdan\,\ Kotayk";
$areanames{en}->{3742233} = "Hrazdan\,\ Kotayk";
$areanames{en}->{3742234} = "Hrazdan\,\ Kotayk";
$areanames{en}->{3742235} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{3742236} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422370} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422371} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422372} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422373} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422374} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422375} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{37422376} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{37422377} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{37422378} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{37422379} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{3742238} = "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk";
$areanames{en}->{374223810} = "Hrazdan\,\ Kotayk";
$areanames{en}->{374223811} = "Hrazdan\,\ Kotayk";
$areanames{en}->{374223812} = "Hrazdan\,\ Kotayk";
$areanames{en}->{374223813} = "Hrazdan\,\ Kotayk";
$areanames{en}->{374223814} = "Hrazdan\,\ Kotayk";
$areanames{en}->{374223815} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{374223816} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{374223817} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{374223818} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{374223819} = "Tsaghkadzor\,\ Kotayk";
$areanames{en}->{37422390} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422391} = "Lernanist\,\ Kotayk";
$areanames{en}->{37422392} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422393} = "Meghradzor\,\ Kotayk";
$areanames{en}->{37422394} = "Pyunik\,\ Kotayk";
$areanames{en}->{37422395} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422396} = "Hrazdan\,\ Kotayk";
$areanames{en}->{37422397} = "Solak\,\ Kotayk";
$areanames{en}->{37422398} = "Bjni\,\ Kotayk";
$areanames{en}->{37422399} = "Hrazdan\,\ Kotayk";
$areanames{en}->{3742240} = "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk";
$areanames{en}->{3742241} = "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk";
$areanames{en}->{3742242} = "Yeghvard\,\ Kotayk";
$areanames{en}->{3742243} = "Yeghvard\,\ Kotayk";
$areanames{en}->{3742244} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{3742245} = "Yeghvard\,\ Kotayk";
$areanames{en}->{37422452} = "Zovuni\,\ Kotayk";
$areanames{en}->{37422453} = "Proshyan\,\ Kotayk";
$areanames{en}->{37422454} = "Argel\,\ Kotayk";
$areanames{en}->{3742246} = "Yeghvard\,\ Kotayk";
$areanames{en}->{3742247} = "Yeghvard\/Nor\ Hajn\,\ Kotayk";
$areanames{en}->{3742248} = "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk";
$areanames{en}->{374224810} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374224811} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374224812} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374224813} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374224814} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374224815} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{374224816} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{374224817} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{374224818} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{374224819} = "Nor\ Hajn\,\ Kotayk";
$areanames{en}->{3742249} = "Yeghvard\,\ Kotayk";
$areanames{en}->{374226} = "Charentsavan\,\ Kotayk";
$areanames{en}->{37422672} = "Arzakan\,\ Kotayk";
$areanames{en}->{37422675} = "Alapars\/Vardanavank\,\ Kotayk";
$areanames{en}->{3742310} = "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir";
$areanames{en}->{3742311} = "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir";
$areanames{en}->{3742312} = "Echmiadzin\,\ Armavir";
$areanames{en}->{3742313} = "Zvartnots\,\ Armavir";
$areanames{en}->{3742314} = "Echmiadzin\,\ Armavir";
$areanames{en}->{3742315} = "Echmiadzin\,\ Armavir";
$areanames{en}->{3742316} = "Echmiadzin\,\ Armavir";
$areanames{en}->{3742317} = "Zvartnots\,\ Armavir";
$areanames{en}->{3742318} = "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir";
$areanames{en}->{37423181} = "Echmiadzin\,\ Armavir";
$areanames{en}->{374231817} = "Zvartnots\,\ Armavir";
$areanames{en}->{374231818} = "Zvartnots\,\ Armavir";
$areanames{en}->{374231819} = "Zvartnots\,\ Armavir";
$areanames{en}->{37423190} = "Baghramyan\,\ Armavir";
$areanames{en}->{37423191} = "Vache\,\ Armavir";
$areanames{en}->{37423192} = "Echmiadzin\,\ Armavir";
$areanames{en}->{37423193} = "Echmiadzin\,\ Armavir";
$areanames{en}->{37423194} = "Echmiadzin\,\ Armavir";
$areanames{en}->{37423195} = "Norakert\,\ Armavir";
$areanames{en}->{37423196} = "Echmiadzin\,\ Armavir";
$areanames{en}->{37423197} = "Echmiadzin\,\ Armavir";
$areanames{en}->{37423198} = "Jrarat\,\ Armavir";
$areanames{en}->{37423199} = "Khoronk\,\ Armavir";
$areanames{en}->{3742320} = "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn";
$areanames{en}->{3742321} = "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn";
$areanames{en}->{3742322} = "Ashtarak\,\ Aragatsotn";
$areanames{en}->{3742323} = "Ashtarak\,\ Aragatsotn";
$areanames{en}->{3742324} = "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn";
$areanames{en}->{3742325} = "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn";
$areanames{en}->{3742326} = "Ashtarak\,\ Aragatsotn";
$areanames{en}->{3742327} = "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn";
$areanames{en}->{3742328} = "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn";
$areanames{en}->{37423281} = "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn";
$areanames{en}->{3742329} = "Ashtarak\,\ Aragatsotn";
$areanames{en}->{37423290} = "Ohanavan\,\ Aragatsotn";
$areanames{en}->{37423294} = "Byurakan\,\ Aragatsotn";
$areanames{en}->{3742330} = "Baghramyan\/Lernagog\,\ Armavir";
$areanames{en}->{3742331} = "Baghramyan\/Lernagog\,\ Armavir";
$areanames{en}->{3742332} = "Baghramyan\,\ Armavir";
$areanames{en}->{3742333} = "Baghramyan\/Myasnikyan\,\ Armavir";
$areanames{en}->{3742334} = "Baghramyan\/Lernagog\,\ Armavir";
$areanames{en}->{3742335} = "Baghramyan\/Lernagog\,\ Armavir";
$areanames{en}->{3742336} = "Baghramyan\,\ Armavir";
$areanames{en}->{3742337} = "Baghramyan\,\ Armavir";
$areanames{en}->{37423374} = "Myasnikyan\,\ Armavir";
$areanames{en}->{37423375} = "Karakert\,\ Armavir";
$areanames{en}->{37423376} = "Dalarik\,\ Armavir";
$areanames{en}->{3742338} = "Baghramyan\/Lernagog\,\ Armavir";
$areanames{en}->{37423381} = "Baghramyan\/Myasnikyan\,\ Armavir";
$areanames{en}->{3742339} = "Baghramyan\,\ Armavir";
$areanames{en}->{374234} = "Ararat\/Vedi\,\ Ararat";
$areanames{en}->{3742340} = "Ararat\/Vedi\/Vosketap\,\ Ararat";
$areanames{en}->{3742341} = "Ararat\/Vedi\/Vosketap\,\ Ararat";
$areanames{en}->{3742345} = "Ararat\/Vedi\/Vosketap\,\ Ararat";
$areanames{en}->{374234510} = "Vedi\,\ Ararat";
$areanames{en}->{374234511} = "Vedi\,\ Ararat";
$areanames{en}->{374234512} = "Vedi\,\ Ararat";
$areanames{en}->{374234513} = "Vedi\,\ Ararat";
$areanames{en}->{374234514} = "Vedi\,\ Ararat";
$areanames{en}->{374234515} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{374234516} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{374234517} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{374234518} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{374234519} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423470} = "Vedi\,\ Ararat";
$areanames{en}->{37423471} = "Vedi\,\ Ararat";
$areanames{en}->{37423472} = "Vedi\,\ Ararat";
$areanames{en}->{37423473} = "Vedi\,\ Ararat";
$areanames{en}->{37423474} = "Vedi\,\ Ararat";
$areanames{en}->{37423475} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423476} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423477} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423478} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423479} = "Ararat\/Urtsadzor\,\ Ararat";
$areanames{en}->{37423481} = "Aygavan\,\ Ararat";
$areanames{en}->{37423486} = "Urtsadzor\,\ Ararat";
$areanames{en}->{37423492} = "Martirosyan\,\ Ararat";
$areanames{en}->{37423497} = "Pokr\ Vedi\,\ Ararat";
$areanames{en}->{37423498} = "Taperakan\,\ Ararat";
$areanames{en}->{3742350} = "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat";
$areanames{en}->{3742351} = "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat";
$areanames{en}->{3742352} = "Artashat\,\ Ararat";
$areanames{en}->{3742353} = "Artashat\/Norashen\,\ Ararat";
$areanames{en}->{3742354} = "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat";
$areanames{en}->{3742355} = "Artashat\,\ Ararat";
$areanames{en}->{3742356} = "Artashat\,\ Ararat";
$areanames{en}->{3742357} = "Artashat\,\ Ararat";
$areanames{en}->{3742358} = "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat";
$areanames{en}->{37423581} = "Artashat\/Norashen\,\ Ararat";
$areanames{en}->{3742359} = "Artashat\/Norashen\,\ Ararat";
$areanames{en}->{3742360} = "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat";
$areanames{en}->{3742361} = "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat";
$areanames{en}->{3742362} = "Masis\,\ Ararat";
$areanames{en}->{3742363} = "Ayntap\/Masis\,\ Ararat";
$areanames{en}->{3742364} = "Masis\,\ Ararat";
$areanames{en}->{3742365} = "Masis\,\ Ararat";
$areanames{en}->{3742366} = "Masis\,\ Ararat";
$areanames{en}->{3742367} = "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat";
$areanames{en}->{3742368} = "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat";
$areanames{en}->{37423681} = "Masis\,\ Ararat";
$areanames{en}->{3742369} = "Masis\,\ Ararat";
$areanames{en}->{37423699} = "Dashtavan\,\ Ararat";
$areanames{en}->{3742370} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{3742371} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{3742372} = "Armavir";
$areanames{en}->{3742373} = "Metsamor\,\ Armavir";
$areanames{en}->{3742374} = "Armavir";
$areanames{en}->{37423747} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{37423748} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{37423749} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{3742375} = "Armavir";
$areanames{en}->{3742376} = "Armavir";
$areanames{en}->{3742377} = "Armavir\/Mrgashat";
$areanames{en}->{37423771} = "Armavir";
$areanames{en}->{37423772} = "Mrgashat\,\ Armavir";
$areanames{en}->{37423779} = "Bambakashat\,\ Armavir";
$areanames{en}->{3742378} = "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir";
$areanames{en}->{37423781} = "Armavir";
$areanames{en}->{3742379} = "Armavir\/Nalbandian";
$areanames{en}->{37423792} = "Nalbandian\,\ Armavir";
$areanames{en}->{37423794} = "Margara\,\ Armavir";
$areanames{en}->{37423796} = "Tandzut\,\ Armavir";
$areanames{en}->{37423798} = "Shenavan\,\ Armavir";
$areanames{en}->{374238} = "Ararat\/Avshar\/Surenavan\/Yeraskh";
$areanames{en}->{3742420} = "Maralik\/Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742421} = "Maralik\/Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742422} = "Maralik\,\ Shirak";
$areanames{en}->{3742423} = "Maralik\,\ Shirak";
$areanames{en}->{37424231} = "Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742424} = "Maralik\,\ Shirak";
$areanames{en}->{3742425} = "Maralik\/Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742426} = "Maralik\,\ Shirak";
$areanames{en}->{3742427} = "Maralik\/Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742428} = "Maralik\/Sarnaghbyur\,\ Shirak";
$areanames{en}->{3742429} = "Maralik\,\ Shirak";
$areanames{en}->{37424293} = "Shirakavan\,\ Shirak";
$areanames{en}->{37424297} = "Ani\ Kayaran\,\ Shirak";
$areanames{en}->{37424300} = "Akhuryan\/Arapi\/Kamo\/Musayelyan\,\ Shirak";
$areanames{en}->{3742440} = "Artik\/Pemzashen\,\ Shirak";
$areanames{en}->{3742441} = "Artik\/Pemzashen\,\ Shirak";
$areanames{en}->{3742442} = "Artik\,\ Shirak";
$areanames{en}->{3742443} = "Artik\,\ Shirak";
$areanames{en}->{3742444} = "Artik\/Panik\,\ Shirak";
$areanames{en}->{3742445} = "Artik\,\ Shirak";
$areanames{en}->{3742446} = "Artik\,\ Shirak";
$areanames{en}->{3742447} = "Artik\/Pemzashen\,\ Shirak";
$areanames{en}->{3742448} = "Artik\/Pemzashen\,\ Shirak";
$areanames{en}->{37424481} = "Artik\/Panik\,\ Shirak";
$areanames{en}->{3742449} = "Artik\,\ Shirak";
$areanames{en}->{37424492} = "Panik\,\ Shirak";
$areanames{en}->{37424495} = "Arevshat\,\ Shirak";
$areanames{en}->{37424496} = "Mets\ Mantash\,\ Shirak";
$areanames{en}->{374245} = "Ashotsk\,\ Shirak";
$areanames{en}->{374246} = "Amasia\,\ Shirak";
$areanames{en}->{374249} = "Talin\,\ Aragatsotn";
$areanames{en}->{3742494} = "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn";
$areanames{en}->{37424973} = "Katnaghbyur\,\ Aragatsotn";
$areanames{en}->{37424981} = "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn";
$areanames{en}->{3742499} = "Aragatsavan\/Talin\,\ Aragatsotn";
$areanames{en}->{37424995} = "Aragats\,\ Aragatsotn";
$areanames{en}->{37424997} = "Mastara\,\ Aragatsotn";
$areanames{en}->{374252} = "Aparan\,\ Aragatsotn";
$areanames{en}->{3742524} = "Aparan\/Artavan\/Kuchak\,\ Aragatsotn";
$areanames{en}->{37425281} = "Aparan\/Artavan\/Kuchak\,\ Aragatsotn";
$areanames{en}->{37425291} = "Kuchak\,\ Aragatsotn";
$areanames{en}->{37425295} = "Artavan\,\ Aragatsotn";
$areanames{en}->{3742530} = "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori";
$areanames{en}->{3742531} = "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori";
$areanames{en}->{3742532} = "Alaverdi\,\ Lori";
$areanames{en}->{3742533} = "Alaverdi\,\ Lori";
$areanames{en}->{3742534} = "Alaverdi\,\ Lori";
$areanames{en}->{3742535} = "Alaverdi\,\ Lori";
$areanames{en}->{37425352} = "Akhtala\,\ Lori";
$areanames{en}->{37425353} = "Shnogh\,\ Lori";
$areanames{en}->{37425356} = "Chochkan\,\ Lori";
$areanames{en}->{37425357} = "Tumanyan\,\ Lori";
$areanames{en}->{3742536} = "Alaverdi\,\ Lori";
$areanames{en}->{3742537} = "Alaverdi\/Akhtala\/Tumanyan\,\ Lori";
$areanames{en}->{3742538} = "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori";
$areanames{en}->{37425381} = "Alaverdi\/Akhtala\/Tumanyan\,\ Lori";
$areanames{en}->{3742539} = "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori";
$areanames{en}->{374254} = "Tashir\,\ Lori";
$areanames{en}->{3742543} = "Tashir\/Metsavan\,\ Lori";
$areanames{en}->{37425481} = "Tashir\/Metsavan\,\ Lori";
$areanames{en}->{3742549} = "Tashir\/Metsavan\,\ Lori";
$areanames{en}->{37425494} = "Metsavan\,\ Lori";
$areanames{en}->{374255} = "Spitak\,\ Lori";
$areanames{en}->{3742560} = "Bovadzor\/Stepanavan\,\ Lori";
$areanames{en}->{3742561} = "Bovadzor\/Stepanavan\,\ Lori";
$areanames{en}->{3742562} = "Stepanavan\,\ Lori";
$areanames{en}->{3742563} = "Stepanavan\,\ Lori";
$areanames{en}->{3742564} = "Stepanavan\,\ Lori";
$areanames{en}->{3742565} = "Bovadzor\/Stepanavan\,\ Lori";
$areanames{en}->{3742566} = "Stepanavan\,\ Lori";
$areanames{en}->{3742567} = "Bovadzor\/Stepanavan\,\ Lori";
$areanames{en}->{3742568} = "Bovadzor\/Stepanavan\,\ Lori";
$areanames{en}->{37425681} = "Stepanavan\,\ Lori";
$areanames{en}->{3742569} = "Stepanavan\,\ Lori";
$areanames{en}->{37425691} = "Kurtan\,\ Lori";
$areanames{en}->{37425694} = "Agarak\,\ Lori";
$areanames{en}->{37425695} = "Lejan\,\ Lori";
$areanames{en}->{374257} = "Aragats\,\ Aragatsotn";
$areanames{en}->{3742570} = "Tsakhkahovit\,\ Aragatsotn";
$areanames{en}->{3742572} = "Tsakhkahovit\,\ Aragatsotn";
$areanames{en}->{3742573} = "Tsakhkahovit\,\ Aragatsotn";
$areanames{en}->{3742576} = "Tsakhkahovit\,\ Aragatsotn";
$areanames{en}->{37425781} = "Tsakhkahovit\,\ Aragatsotn";
$areanames{en}->{374261} = "Sevan\,\ Gegharkunik";
$areanames{en}->{374262} = "Martuni\,\ Gegharkunik";
$areanames{en}->{3742623} = "Martuni\/Vardenik\,\ Gegharkunik";
$areanames{en}->{37426252} = "Vardenik\,\ Gegharkunik";
$areanames{en}->{37426253} = "Vardenik\,\ Gegharkunik";
$areanames{en}->{37426272} = "Lichk\,\ Gegharkunik";
$areanames{en}->{37426281} = "Martuni\/Vardenik\,\ Gegharkunik";
$areanames{en}->{37426299} = "Eranos\,\ Gegharkunik";
$areanames{en}->{3742630} = "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush";
$areanames{en}->{3742631} = "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush";
$areanames{en}->{3742632} = "Ijevan\/Aygehovit\/Achajur\,\ Tavush";
$areanames{en}->{3742633} = "Ijevan\,\ Tavush";
$areanames{en}->{3742634} = "Ijevan\,\ Tavush";
$areanames{en}->{3742635} = "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush";
$areanames{en}->{3742636} = "Ijevan\,\ Tavush";
$areanames{en}->{3742637} = "Ijevan\,\ Tavush";
$areanames{en}->{37426374} = "Aygehovit\,\ Tavush";
$areanames{en}->{3742638} = "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush";
$areanames{en}->{37426381} = "Ijevan\/Aygehovit\/Achajur\,\ Tavush";
$areanames{en}->{3742639} = "Ijevan\,\ Tavush";
$areanames{en}->{37426392} = "Achajur\,\ Tavush";
$areanames{en}->{37426397} = "Azatamut\,\ Tavush";
$areanames{en}->{374264} = "Gavar\,\ Gegharkunik";
$areanames{en}->{3742640} = "Gavar\/Sarukhan\,\ Gegharkunik";
$areanames{en}->{3742641} = "Gavar\/Sarukhan\,\ Gegharkunik";
$areanames{en}->{3742647} = "Gavar\/Sarukhan\,\ Gegharkunik";
$areanames{en}->{3742648} = "Gavar\/Sarukhan\,\ Gegharkunik";
$areanames{en}->{374265} = "Tchambarak\,\ Gegharkunik";
$areanames{en}->{3742654} = "Tchambarak\/Vahan\,\ Gegharkunik";
$areanames{en}->{37426581} = "Tchambarak\/Vahan\,\ Gegharkunik";
$areanames{en}->{37426596} = "Vahan\,\ Gegharkunik";
$areanames{en}->{3742660} = "Berdavan\/Koghb\/Noyemberyan\,\ Tavush";
$areanames{en}->{3742661} = "Berdavan\/Koghb\/Noyemberyan\,\ Tavush";
$areanames{en}->{3742662} = "Noyemberyan\,\ Tavush";
$areanames{en}->{3742663} = "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush";
$areanames{en}->{3742664} = "Berdavan\/Koghb\/Noyemberyan\,\ Tavush";
$areanames{en}->{3742665} = "Koghb\/Noyemberyan\,\ Tavush";
$areanames{en}->{37426652} = "Koghb\,\ Tavush";
$areanames{en}->{37426653} = "Koghb\,\ Tavush";
$areanames{en}->{3742666} = "Noyemberyan\,\ Tavush";
$areanames{en}->{3742667} = "Berdavan\/Noyemberyan\,\ Tavush";
$areanames{en}->{3742668} = "Berdavan\/Koghb\/Noyemberyan\,\ Tavush";
$areanames{en}->{37426681} = "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush";
$areanames{en}->{37426690} = "Noyemberyan\,\ Tavush";
$areanames{en}->{37426691} = "Noyemberyan\,\ Tavush";
$areanames{en}->{37426692} = "Archis\,\ Tavush";
$areanames{en}->{37426693} = "Baghanis\,\ Tavush";
$areanames{en}->{37426694} = "Noyemberyan\,\ Tavush";
$areanames{en}->{37426695} = "Zorakan\,\ Tavush";
$areanames{en}->{37426696} = "Voskepar\,\ Tavush";
$areanames{en}->{37426697} = "Noyemberyan\,\ Tavush";
$areanames{en}->{37426698} = "Noyemberyan\,\ Tavush";
$areanames{en}->{37426699} = "Koti\,\ Tavush";
$areanames{en}->{3742670} = "Aygepar\/Berd\,\ Tavush";
$areanames{en}->{3742671} = "Aygepar\/Berd\,\ Tavush";
$areanames{en}->{3742672} = "Berd\,\ Tavush";
$areanames{en}->{3742673} = "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush";
$areanames{en}->{3742674} = "Aygepar\/Berd\,\ Tavush";
$areanames{en}->{3742675} = "Artsvaberd\/Berd\,\ Tavush";
$areanames{en}->{3742676} = "Berd\,\ Tavush";
$areanames{en}->{3742677} = "Berd\,\ Tavush";
$areanames{en}->{3742678} = "Aygepar\/Berd\,\ Tavush";
$areanames{en}->{37426781} = "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush";
$areanames{en}->{3742679} = "Berd\,\ Tavush";
$areanames{en}->{37426791} = "Navur\,\ Tavush";
$areanames{en}->{37426794} = "Tovuz\,\ Tavush";
$areanames{en}->{37426796} = "Mosesgegh\,\ Tavush";
$areanames{en}->{37426797} = "Norashen\,\ Tavush";
$areanames{en}->{3742680} = "Dilijan\,\ Tavush";
$areanames{en}->{3742682} = "Dilijan\,\ Tavush";
$areanames{en}->{3742683} = "Dilijan\,\ Tavush";
$areanames{en}->{3742684} = "Dilijan\/Haghartsin\/Teghut\,\ Tavush";
$areanames{en}->{3742686} = "Dilijan\,\ Tavush";
$areanames{en}->{37426881} = "Dilijan\/Haghartsin\/Teghut\,\ Tavush";
$areanames{en}->{3742689} = "Dilijan\,\ Tavush";
$areanames{en}->{37426895} = "Haghartsin\,\ Tavush";
$areanames{en}->{37426897} = "Teghut\,\ Tavush";
$areanames{en}->{374269} = "Vardenis\,\ Gegharkunik";
$areanames{en}->{3742810} = "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742811} = "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742812} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742813} = "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor";
$areanames{en}->{3742814} = "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742815} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428151} = "Khachik\,\ Vayots\ dzor";
$areanames{en}->{3742816} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742817} = "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{3742818} = "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428181} = "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor";
$areanames{en}->{37428190} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428191} = "Arpi\,\ Vayots\ dzor";
$areanames{en}->{37428192} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428193} = "Aghavnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428194} = "Areni\,\ Vayots\ dzor";
$areanames{en}->{37428195} = "Malishka\,\ Vayots\ dzor";
$areanames{en}->{37428196} = "Yeghegnadzor\,\ Vayots\ dzor";
$areanames{en}->{37428197} = "Yelpin\,\ Vayots\ dzor";
$areanames{en}->{37428198} = "Rind\,\ Vayots\ dzor";
$areanames{en}->{37428199} = "Shatin\,\ Vayots\ dzor";
$areanames{en}->{374282} = "Vayk\,\ Vayots\ dzor";
$areanames{en}->{3742830} = "Sisian\,\ Syunik";
$areanames{en}->{3742832} = "Sisian\,\ Syunik";
$areanames{en}->{3742833} = "Sisian\,\ Syunik";
$areanames{en}->{37428351} = "Sisian\,\ Syunik";
$areanames{en}->{3742836} = "Sisian\,\ Syunik";
$areanames{en}->{3742837} = "Sisian\,\ Syunik";
$areanames{en}->{37428375} = "Tasik\,\ Syunik";
$areanames{en}->{3742838} = "Sisian\,\ Syunik";
$areanames{en}->{3742839} = "Sisian\,\ Syunik";
$areanames{en}->{37428396} = "Angehakot\,\ Syunik";
$areanames{en}->{374284} = "Goris\,\ Syunik";
$areanames{en}->{3742840} = "Goris\/Verishen\,\ Syunik";
$areanames{en}->{3742841} = "Goris\/Verishen\,\ Syunik";
$areanames{en}->{37428427} = "Verishen\,\ Syunik";
$areanames{en}->{3742847} = "Goris\/Verishen\,\ Syunik";
$areanames{en}->{3742848} = "Goris\/Verishen\,\ Syunik";
$areanames{en}->{37428491} = "Harzhis\,\ Syunik";
$areanames{en}->{37428494} = "Khndzoresk\,\ Syunik";
$areanames{en}->{37428495} = "Shinuhayr\,\ Syunik";
$areanames{en}->{37428499} = "Kornidzor\,\ Syunik";
$areanames{en}->{3742850} = "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik";
$areanames{en}->{3742851} = "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik";
$areanames{en}->{3742852} = "Kapan\,\ Syunik";
$areanames{en}->{3742853} = "Kajaran\,\ Syunik";
$areanames{en}->{37428540} = "Kapan\,\ Syunik";
$areanames{en}->{37428541} = "Kapan\,\ Syunik";
$areanames{en}->{37428542} = "Kapan\,\ Syunik";
$areanames{en}->{37428543} = "Kapan\,\ Syunik";
$areanames{en}->{37428544} = "Kapan\,\ Syunik";
$areanames{en}->{37428545} = "Kajaran\,\ Syunik";
$areanames{en}->{37428546} = "Kajaran\,\ Syunik";
$areanames{en}->{37428547} = "Kajaran\,\ Syunik";
$areanames{en}->{37428548} = "Kajaran\,\ Syunik";
$areanames{en}->{37428549} = "Kajaran\,\ Syunik";
$areanames{en}->{3742855} = "Kapan\,\ Syunik";
$areanames{en}->{3742856} = "Kapan\,\ Syunik";
$areanames{en}->{3742857} = "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik";
$areanames{en}->{3742858} = "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik";
$areanames{en}->{374285810} = "Kapan\,\ Syunik";
$areanames{en}->{374285811} = "Kapan\,\ Syunik";
$areanames{en}->{374285812} = "Kapan\,\ Syunik";
$areanames{en}->{374285813} = "Kapan\,\ Syunik";
$areanames{en}->{374285814} = "Kapan\,\ Syunik";
$areanames{en}->{374285815} = "Kajaran\,\ Syunik";
$areanames{en}->{374285816} = "Kajaran\,\ Syunik";
$areanames{en}->{374285817} = "Kajaran\,\ Syunik";
$areanames{en}->{374285818} = "Kajaran\,\ Syunik";
$areanames{en}->{374285819} = "Kajaran\,\ Syunik";
$areanames{en}->{3742859} = "Kapan\,\ Syunik";
$areanames{en}->{3742860} = "Meghri\/Agarak\,\ Syunik";
$areanames{en}->{3742861} = "Meghri\/Agarak\,\ Syunik";
$areanames{en}->{3742862} = "Agarak\,\ Syunik";
$areanames{en}->{3742863} = "Meghri\,\ Syunik";
$areanames{en}->{3742864} = "Meghri\,\ Syunik";
$areanames{en}->{3742865} = "Agarak\/Shvanidzor\,\ Syunik";
$areanames{en}->{3742866} = "Meghri\,\ Syunik";
$areanames{en}->{3742867} = "Meghri\/Agarak\,\ Syunik";
$areanames{en}->{3742868} = "Meghri\/Agarak\,\ Syunik";
$areanames{en}->{374286810} = "Meghri\,\ Syunik";
$areanames{en}->{374286811} = "Meghri\,\ Syunik";
$areanames{en}->{374286812} = "Meghri\,\ Syunik";
$areanames{en}->{374286813} = "Meghri\,\ Syunik";
$areanames{en}->{374286814} = "Meghri\,\ Syunik";
$areanames{en}->{374286815} = "Agarak\/Meghri\,\ Syunik";
$areanames{en}->{374286816} = "Agarak\/Meghri\,\ Syunik";
$areanames{en}->{374286817} = "Agarak\/Meghri\,\ Syunik";
$areanames{en}->{374286818} = "Agarak\/Meghri\,\ Syunik";
$areanames{en}->{374286819} = "Agarak\/Meghri\,\ Syunik";
$areanames{en}->{3742869} = "Meghri\,\ Syunik";
$areanames{en}->{37428695} = "Shvanidzor\,\ Syunik";
$areanames{en}->{374287} = "Jermuk\,\ Vayots\ dzor";
$areanames{en}->{3742873} = "Jermuk\/Gndevaz\,\ Vayots\ dzor";
$areanames{en}->{37428781} = "Jermuk\/Gndevaz\,\ Vayots\ dzor";
$areanames{en}->{37428794} = "Gndevaz\,\ Vayots\ dzor";
$areanames{en}->{374312} = "Gyumri\,\ Shirak";
$areanames{en}->{3743120} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{3743121} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{3743127} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431280} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431281} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431282} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431283} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431284} = "Akhuryan\,\ Shirak";
$areanames{en}->{374312859} = "Akhuryan\,\ Shirak";
$areanames{en}->{37431286} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{37431287} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{37431288} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{37431289} = "Gyumri\/Akhuryan\,\ Shirak";
$areanames{en}->{374322} = "Vanadzor\,\ Lori";
$areanames{en}->{3743220} = "Vanadzor\/Gugark\,\ Lori";
$areanames{en}->{3743221} = "Vanadzor\/Gugark\,\ Lori";
$areanames{en}->{3743228} = "Vanadzor\/Gugark\,\ Lori";
$areanames{en}->{37432293} = "Pambak\,\ Lori";
$areanames{en}->{37432294} = "Lernapat\,\ Lori";
$areanames{en}->{37432295} = "Yeghegnut\,\ Lori";
$areanames{en}->{37432296} = "Margahovit\,\ Lori";
$areanames{en}->{37432297} = "Dzoraget\,\ Lori";
$areanames{en}->{37432298} = "Lermontovo\,\ Lori";
$areanames{en}->{37432299} = "Vahagni\,\ Lori";
$areanames{en}->{374470} = "Nagorno\-Karabakh";
$areanames{en}->{374471} = "Stepanakert";
$areanames{en}->{374472} = "Nagorno\-Karabakh";
$areanames{en}->{374473} = "Nagorno\-Karabakh";
$areanames{en}->{374474} = "Martakert";
$areanames{en}->{374475} = "Hadrut";
$areanames{en}->{374476} = "Askeran";
$areanames{en}->{374477} = "Shushi";
$areanames{en}->{37447732} = "Berdzor\/Kashatagh";
$areanames{en}->{374478} = "Martuni";
$areanames{en}->{374479} = "Stepanakert";
$areanames{hy}->{37410} = "Երևան\/Ջրվեժ";
$areanames{hy}->{37411} = "Երևան";
$areanames{hy}->{37412} = "Երևան";
$areanames{hy}->{37415} = "Երևան";
$areanames{hy}->{3742220} = "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք";
$areanames{hy}->{3742221} = "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք";
$areanames{hy}->{3742222} = "Աբովյան\,\ Կոտայք";
$areanames{hy}->{3742223} = "Աբովյան\,\ Կոտայք";
$areanames{hy}->{3742224} = "Աբովյան\,\ Կոտայք";
$areanames{hy}->{3742225} = "Աբովյան\/Արզնի\/Առինջ\/Գեղաշեն\,\ Կոտայք";
$areanames{hy}->{3742226} = "Աբովյան\,\ Կոտայք";
$areanames{hy}->{3742227} = "Գառնի\/Աբովյան\,\ Կոտայք";
$areanames{hy}->{3742228} = "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք";
$areanames{hy}->{37422281} = "Աբովյան\/Արզնի\/Առինջ\/Գեղաշեն\,\ Կոտայք";
$areanames{hy}->{37422290} = "Մայակովսկի\,\ Կոտայք";
$areanames{hy}->{37422291} = "Բալահովիտ\/Կամարիս\,\ Կոտայք";
$areanames{hy}->{37422292} = "Զովք\/Աբովյան\,\ Կոտայք";
$areanames{hy}->{37422293} = "Արամուս\,\ Կոտայք";
$areanames{hy}->{37422294} = "Արզնի\,\ Կոտայք";
$areanames{hy}->{37422295} = "Զովք\/Աբովյան\,\ Կոտայք";
$areanames{hy}->{37422296} = "Պտղնի\,\ Կոտայք";
$areanames{hy}->{37422297} = "Գեղաշեն\,\ Կոտայք";
$areanames{hy}->{37422298} = "Առինջ\,\ Կոտայք";
$areanames{hy}->{37422299} = "Կոտայք";
$areanames{hy}->{3742230} = "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{3742231} = "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{3742232} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{3742233} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{3742234} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{3742235} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{3742236} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422370} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422371} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422372} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422373} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422374} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422375} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{37422376} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{37422377} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{37422378} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{37422379} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{3742238} = "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{374223810} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{374223811} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{374223812} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{374223813} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{374223814} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{374223815} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{374223816} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{374223817} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{374223818} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{374223819} = "Ծաղկաձոր\,\ Կոտայք";
$areanames{hy}->{37422390} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422391} = "Լեռնանիստ\,\ Կոտայք";
$areanames{hy}->{37422392} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422393} = "Մեղրաձոր\,\ Կոտայք";
$areanames{hy}->{37422394} = "Փյունիք\,\ Կոտայք";
$areanames{hy}->{37422395} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422396} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{37422397} = "Սոլակ\,\ Կոտայք";
$areanames{hy}->{37422398} = "Բջնի\,\ Կոտայք";
$areanames{hy}->{37422399} = "Հրազդան\,\ Կոտայք";
$areanames{hy}->{3742240} = "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք";
$areanames{hy}->{3742241} = "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք";
$areanames{hy}->{3742242} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{3742243} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{3742244} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{3742245} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{37422452} = "Զովունի\,\ Կոտայք";
$areanames{hy}->{37422453} = "Պռոշյան\,\ Կոտայք";
$areanames{hy}->{37422454} = "Արգել\,\ Կոտայք";
$areanames{hy}->{3742246} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{3742247} = "Եղվարդ\/Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{3742248} = "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224810} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224811} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224812} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224813} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224814} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374224815} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{374224816} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{374224817} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{374224818} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{374224819} = "Նոր\ Հաճն\,\ Կոտայք";
$areanames{hy}->{3742249} = "Եղվարդ\,\ Կոտայք";
$areanames{hy}->{374226} = "Չարենցավան\,\ Կոտայք";
$areanames{hy}->{37422672} = "Արզական\,\ Կոտայք";
$areanames{hy}->{37422675} = "Ալապարս\/Վարդանավանք\,\ Կոտայք";
$areanames{hy}->{3742310} = "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{3742311} = "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{3742312} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{3742313} = "Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{3742314} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{3742315} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{3742316} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{3742317} = "Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{3742318} = "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{37423181} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{374231817} = "Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{374231818} = "Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{374231819} = "Զվարթնոց\,\ Արմավիր";
$areanames{hy}->{37423190} = "Բաղրամյան\,\ Արմավիր";
$areanames{hy}->{37423191} = "Վաչե\,\ Արմավիր";
$areanames{hy}->{37423192} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{37423193} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{37423194} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{37423195} = "Նորակերտ\,\ Արմավիր";
$areanames{hy}->{37423196} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{37423197} = "Էջմիածին\,\ Արմավիր";
$areanames{hy}->{37423198} = "Ջրառատ\,\ Արմավիր";
$areanames{hy}->{37423199} = "Խորոնք\,\ Արմավիր";
$areanames{hy}->{3742320} = "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն";
$areanames{hy}->{3742321} = "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն";
$areanames{hy}->{3742322} = "Աշտարակ\,\ Արագածոտն";
$areanames{hy}->{3742323} = "Աշտարակ\,\ Արագածոտն";
$areanames{hy}->{3742324} = "Աշտարակ\/Բյուրական\/Օհանավան\,\ Արագածոտն";
$areanames{hy}->{3742325} = "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն";
$areanames{hy}->{3742326} = "Աշտարակ\,\ Արագածոտն";
$areanames{hy}->{3742327} = "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն";
$areanames{hy}->{3742328} = "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն";
$areanames{hy}->{37423281} = "Աշտարակ\/Բյուրական\/Օհանավան\,\ Արագածոտն";
$areanames{hy}->{3742329} = "Աշտարակ\,\ Արագածոտն";
$areanames{hy}->{37423290} = "Օհանավան\,\ Արագածոտն";
$areanames{hy}->{37423294} = "Բյուրական\,\ Արագածոտն";
$areanames{hy}->{3742330} = "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր";
$areanames{hy}->{3742331} = "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր";
$areanames{hy}->{3742332} = "Բաղրամյան\,\ Արմավիր";
$areanames{hy}->{3742333} = "Բաղրամյան\/Մյասնիկյան\,\ Արմավիր";
$areanames{hy}->{3742334} = "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր";
$areanames{hy}->{3742335} = "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր";
$areanames{hy}->{3742336} = "Բաղրամյան\,\ Արմավիր";
$areanames{hy}->{3742337} = "Բաղրամյան\,\ Արմավիր";
$areanames{hy}->{37423374} = "Մյասնիկյան\,\ Արմավիր";
$areanames{hy}->{37423375} = "Քարակերտ\,\ Արմավիր";
$areanames{hy}->{37423376} = "Դալարիկ\,\ Արմավիր";
$areanames{hy}->{3742338} = "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր";
$areanames{hy}->{37423381} = "Բաղրամյան\/Մյասնիկյան\,\ Արմավիր";
$areanames{hy}->{3742339} = "Բաղրամյան\,\ Արմավիր";
$areanames{hy}->{374234} = "Արարատ\/Վեդի\,\ Արարատ";
$areanames{hy}->{3742340} = "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ";
$areanames{hy}->{3742341} = "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ";
$areanames{hy}->{3742345} = "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ";
$areanames{hy}->{374234510} = "Վեդի\,\ Արարատ";
$areanames{hy}->{374234511} = "Վեդի\,\ Արարատ";
$areanames{hy}->{374234512} = "Վեդի\,\ Արարատ";
$areanames{hy}->{374234513} = "Վեդի\,\ Արարատ";
$areanames{hy}->{374234514} = "Վեդի\,\ Արարատ";
$areanames{hy}->{374234515} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{374234516} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{374234517} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{374234518} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{374234519} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423470} = "Վեդի\,\ Արարատ";
$areanames{hy}->{37423471} = "Վեդի\,\ Արարատ";
$areanames{hy}->{37423472} = "Վեդի\,\ Արարատ";
$areanames{hy}->{37423473} = "Վեդի\,\ Արարատ";
$areanames{hy}->{37423474} = "Վեդի\,\ Արարատ";
$areanames{hy}->{37423475} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423476} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423477} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423478} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423479} = "Արարատ\/Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423481} = "Այգավան\,\ Արարատ";
$areanames{hy}->{37423486} = "Ուրցաձոր\,\ Արարատ";
$areanames{hy}->{37423492} = "Մարտիրոսյան\,\ Արարատ";
$areanames{hy}->{37423497} = "Փոքր\ Վեդի\,\ Արարատ";
$areanames{hy}->{37423498} = "Տափերական\,\ Արարատ";
$areanames{hy}->{3742350} = "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ";
$areanames{hy}->{3742351} = "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ";
$areanames{hy}->{3742352} = "Արտաշատ\,\ Արարատ";
$areanames{hy}->{3742353} = "Արտաշատ\/Նորաշեն\,\ Արարատ";
$areanames{hy}->{3742354} = "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ";
$areanames{hy}->{3742355} = "Արտաշատ\,\ Արարատ";
$areanames{hy}->{3742356} = "Արտաշատ\,\ Արարատ";
$areanames{hy}->{3742357} = "Արտաշատ\,\ Արարատ";
$areanames{hy}->{3742358} = "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ";
$areanames{hy}->{37423581} = "Արտաշատ\/Նորաշեն\,\ Արարատ";
$areanames{hy}->{3742359} = "Արտաշատ\/Նորաշեն\,\ Արարատ";
$areanames{hy}->{3742360} = "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ";
$areanames{hy}->{3742361} = "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ";
$areanames{hy}->{3742362} = "Մասիս\,\ Արարատ";
$areanames{hy}->{3742363} = "Այնթապ\/Մասիս\,\ Արարատ";
$areanames{hy}->{3742364} = "Մասիս\,\ Արարատ";
$areanames{hy}->{3742365} = "Մասիս\,\ Արարատ";
$areanames{hy}->{3742366} = "Մասիս\,\ Արարատ";
$areanames{hy}->{3742367} = "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ";
$areanames{hy}->{3742368} = "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ";
$areanames{hy}->{37423681} = "Մասիս\,\ Արարատ";
$areanames{hy}->{3742369} = "Մասիս\,\ Արարատ";
$areanames{hy}->{37423699} = "Դաշտավան\,\ Արարատ";
$areanames{hy}->{3742370} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{3742371} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{3742372} = "Արմավիր";
$areanames{hy}->{3742373} = "Մեծամոր\,\ Արմավիր";
$areanames{hy}->{3742374} = "Արմավիր";
$areanames{hy}->{37423747} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{37423748} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{37423749} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{3742375} = "Արմավիր";
$areanames{hy}->{3742376} = "Արմավիր";
$areanames{hy}->{3742377} = "Արմավիր\/Մրգաշատ";
$areanames{hy}->{37423771} = "Արմավիր";
$areanames{hy}->{37423772} = "Մրգաշատ\,\ Արմավիր";
$areanames{hy}->{37423779} = "Բամբակաշատ\,\ Արմավիր";
$areanames{hy}->{3742378} = "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր";
$areanames{hy}->{37423781} = "Արմավիր";
$areanames{hy}->{3742379} = "Արմավիր\/Նալբանդյան";
$areanames{hy}->{37423792} = "Նալբանդյան\,\ Արմավիր";
$areanames{hy}->{37423794} = "Մարգարա\,\ Արմավիր";
$areanames{hy}->{37423796} = "Տանձուտ\,\ Արմավիր";
$areanames{hy}->{37423798} = "Շենավան\,\ Արմավիր";
$areanames{hy}->{374238} = "Արարատ\/Ավշար\/Սուրենավան\/Երասխ";
$areanames{hy}->{3742420} = "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742421} = "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742422} = "Մարալիկ\,\ Շիրակ";
$areanames{hy}->{3742423} = "Մարալիկ\,\ Շիրակ";
$areanames{hy}->{37424231} = "Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742424} = "Մարալիկ\,\ Շիրակ";
$areanames{hy}->{3742425} = "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742426} = "Մարալիկ\,\ Շիրակ";
$areanames{hy}->{3742427} = "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742428} = "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ";
$areanames{hy}->{3742429} = "Մարալիկ\,\ Շիրակ";
$areanames{hy}->{37424293} = "Շիրակավան\,\ Շիրակ";
$areanames{hy}->{37424297} = "Անի\ Կայարան\,\ Շիրակ";
$areanames{hy}->{37424300} = "Ախուրյան\/Առափի\/Կամո\/Մուսայելյան\,\ Շիրակ";
$areanames{hy}->{3742440} = "Արթիկ\/Պեմզաշեն\,\ Շիրակ";
$areanames{hy}->{3742441} = "Արթիկ\/Պեմզաշեն\,\ Շիրակ";
$areanames{hy}->{3742442} = "Արթիկ\,\ Շիրակ";
$areanames{hy}->{3742443} = "Արթիկ\,\ Շիրակ";
$areanames{hy}->{3742444} = "Արթիկ\/Փանիկ\,\ Շիրակ";
$areanames{hy}->{3742445} = "Արթիկ\,\ Շիրակ";
$areanames{hy}->{3742446} = "Արթիկ\,\ Շիրակ";
$areanames{hy}->{3742447} = "Արթիկ\/Պեմզաշեն\,\ Շիրակ";
$areanames{hy}->{3742448} = "Արթիկ\/Պեմզաշեն\,\ Շիրակ";
$areanames{hy}->{37424481} = "Արթիկ\/Փանիկ\,\ Շիրակ";
$areanames{hy}->{3742449} = "Արթիկ\,\ Շիրակ";
$areanames{hy}->{37424492} = "Փանիկ\,\ Շիրակ";
$areanames{hy}->{37424495} = "Արևշատ\,\ Շիրակ";
$areanames{hy}->{37424496} = "Մեծ\ Մանթաշ\,\ Շիրակ";
$areanames{hy}->{374245} = "Աշոցք\,\ Շիրակ";
$areanames{hy}->{374246} = "Ամասիա\,\ Շիրակ";
$areanames{hy}->{374249} = "Թալին\,\ Արագածոտն";
$areanames{hy}->{3742494} = "Թալին\/Արագած\/Կաթնաղբյուր\/Մաստարա\,\ Արագածոտն";
$areanames{hy}->{37424973} = "Կաթնաղբյուր\,\ Արագածոտն";
$areanames{hy}->{37424981} = "Թալին\/Արագած\/Կաթնաղբյուր\/Մաստարա\,\ Արագածոտն";
$areanames{hy}->{3742499} = "Արագածավան\/Թալին\,\ Արագածոտն";
$areanames{hy}->{37424995} = "Արագած\,\ Արագածոտն";
$areanames{hy}->{37424997} = "Մաստարա\,\ Արագածոտն";
$areanames{hy}->{374252} = "Ապարան\,\ Արագածոտն";
$areanames{hy}->{3742524} = "Ապարան\/Արտավան\/Քուչակ\,\ Արագածոտն";
$areanames{hy}->{37425281} = "Ապարան\/Արտավան\/Քուչակ\,\ Արագածոտն";
$areanames{hy}->{37425291} = "Քուչակ\,\ Արագածոտն";
$areanames{hy}->{37425295} = "Արտավան\,\ Արագածոտն";
$areanames{hy}->{3742530} = "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի";
$areanames{hy}->{3742531} = "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի";
$areanames{hy}->{3742532} = "Ալավերդի\,\ Լոռի";
$areanames{hy}->{3742533} = "Ալավերդի\,\ Լոռի";
$areanames{hy}->{3742534} = "Ալավերդի\,\ Լոռի";
$areanames{hy}->{3742535} = "Ալավերդի\,\ Լոռի";
$areanames{hy}->{37425352} = "Ախթալա\,\ Լոռի";
$areanames{hy}->{37425353} = "Շնող\,\ Լոռի";
$areanames{hy}->{37425356} = "Ճոճկան\,\ Լոռի";
$areanames{hy}->{37425357} = "Թումանյան\,\ Լոռի";
$areanames{hy}->{3742536} = "Ալավերդի\,\ Լոռի";
$areanames{hy}->{3742537} = "Ալավերդի\/Ախթալա\/Թումանյան\,\ Լոռի";
$areanames{hy}->{3742538} = "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի";
$areanames{hy}->{37425381} = "Ալավերդի\/Ախթալա\/Թումանյան\,\ Լոռի";
$areanames{hy}->{3742539} = "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի";
$areanames{hy}->{374254} = "Տաշիր\,\ Լոռի";
$areanames{hy}->{3742543} = "Տաշիր\/Մեծավան\,\ Լոռի";
$areanames{hy}->{37425481} = "Տաշիր\/Մեծավան\,\ Լոռի";
$areanames{hy}->{3742549} = "Տաշիր\/Մեծավան\,\ Լոռի";
$areanames{hy}->{37425494} = "Մեծավան\,\ Լոռի";
$areanames{hy}->{374255} = "Սպիտակ\,\ Լոռի";
$areanames{hy}->{3742560} = "Բովաձոր\/Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742561} = "Բովաձոր\/Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742562} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742563} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742564} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742565} = "Բովաձոր\/Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742566} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742567} = "Բովաձոր\/Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742568} = "Բովաձոր\/Ստեփանավան\,\ Լոռի";
$areanames{hy}->{37425681} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{3742569} = "Ստեփանավան\,\ Լոռի";
$areanames{hy}->{37425691} = "Կուրթան\,\ Լոռի";
$areanames{hy}->{37425694} = "Ագարակ\,\ Լոռի";
$areanames{hy}->{37425695} = "Լեջան\,\ Լոռի";
$areanames{hy}->{374257} = "Արագած\,\ Արագածոտն";
$areanames{hy}->{3742570} = "Ծաղկահովիտ\,\ Արագածոտն";
$areanames{hy}->{3742572} = "Ծաղկահովիտ\,\ Արագածոտն";
$areanames{hy}->{3742573} = "Ծաղկահովիտ\,\ Արագածոտն";
$areanames{hy}->{3742576} = "Ծաղկահովիտ\,\ Արագածոտն";
$areanames{hy}->{37425781} = "Ծաղկահովիտ\,\ Արագածոտն";
$areanames{hy}->{374261} = "Սևան\,\ Գեղարքունիք";
$areanames{hy}->{374262} = "Մարտունի\,\ Գեղարքունիք";
$areanames{hy}->{3742623} = "Մարտունի\/Վարդենիկ\,\ Գեղարքունիք";
$areanames{hy}->{37426252} = "Վարդենիկ\,\ Գեղարքունիք";
$areanames{hy}->{37426253} = "Վարդենիկ\,\ Գեղարքունիք";
$areanames{hy}->{37426272} = "Լիճք\,\ Գեղարքունիք";
$areanames{hy}->{37426281} = "Մարտունի\/Վարդենիկ\,\ Գեղարքունիք";
$areanames{hy}->{37426299} = "Երանոս\,\ Գեղարքունիք";
$areanames{hy}->{3742630} = "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ";
$areanames{hy}->{3742631} = "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ";
$areanames{hy}->{3742632} = "Իջեւան\/Այգեհովիտ\/Աչաջուր\,\ Տավուշ";
$areanames{hy}->{3742633} = "Իջեւան\,\ Տավուշ";
$areanames{hy}->{3742634} = "Իջեւան\,\ Տավուշ";
$areanames{hy}->{3742635} = "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ";
$areanames{hy}->{3742636} = "Իջեւան\,\ Տավուշ";
$areanames{hy}->{3742637} = "Իջեւան\,\ Տավուշ";
$areanames{hy}->{37426374} = "Այգեհովիտ\,\ Տավուշ";
$areanames{hy}->{3742638} = "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ";
$areanames{hy}->{37426381} = "Իջեւան\/Այգեհովիտ\/Աչաջուր\,\ Տավուշ";
$areanames{hy}->{3742639} = "Իջեւան\,\ Տավուշ";
$areanames{hy}->{37426392} = "Աչաջուր\,\ Տավուշ";
$areanames{hy}->{37426397} = "Ազատամուտ\,\ Տավուշ";
$areanames{hy}->{374264} = "Գավառ\,\ Գեղարքունիք";
$areanames{hy}->{3742640} = "Գավառ\/Սարուխան\,\ Գեղարքունիք";
$areanames{hy}->{3742641} = "Գավառ\/Սարուխան\,\ Գեղարքունիք";
$areanames{hy}->{3742647} = "Գավառ\/Սարուխան\,\ Գեղարքունիք";
$areanames{hy}->{3742648} = "Գավառ\/Սարուխան\,\ Գեղարքունիք";
$areanames{hy}->{374265} = "Ճամբարակ\,\ Գեղարքունիք";
$areanames{hy}->{3742654} = "Ճամբարակ\/Վահան\,\ Գեղարքունիք";
$areanames{hy}->{37426581} = "Ճամբարակ\/Վահան\,\ Գեղարքունիք";
$areanames{hy}->{37426596} = "Վահան\,\ Գեղարքունիք";
$areanames{hy}->{3742660} = "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742661} = "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742662} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742663} = "Նոյեմբերյան\/Ոսկեպար\/Կոթի\/Կողբ\,\ Տավուշ";
$areanames{hy}->{3742664} = "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742665} = "Կողբ\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426652} = "Կողբ\,\ Տավուշ";
$areanames{hy}->{37426653} = "Կողբ\,\ Տավուշ";
$areanames{hy}->{3742666} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742667} = "Բերդավան\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{3742668} = "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426681} = "Նոյեմբերյան\/Ոսկեպար\/Կոթի\/Կողբ\,\ Տավուշ";
$areanames{hy}->{37426690} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426691} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426692} = "Արճիս\,\ Տավուշ";
$areanames{hy}->{37426693} = "Բաղանիս\,\ Տավուշ";
$areanames{hy}->{37426694} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426695} = "Զորական\,\ Տավուշ";
$areanames{hy}->{37426696} = "Ոսկեպար\,\ Տավուշ";
$areanames{hy}->{37426697} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426698} = "Նոյեմբերյան\,\ Տավուշ";
$areanames{hy}->{37426699} = "Կոթի\,\ Տավուշ";
$areanames{hy}->{3742670} = "Այգեպար\/Բերդ\,\ Տավուշ";
$areanames{hy}->{3742671} = "Այգեպար\/Բերդ\,\ Տավուշ";
$areanames{hy}->{3742672} = "Բերդ\,\ Տավուշ";
$areanames{hy}->{3742673} = "Բերդ\/Մոսեսգեղ\/Նավուր\/Նորաշեն\,\ Տավուշ";
$areanames{hy}->{3742674} = "Այգեպար\/Բերդ\,\ Տավուշ";
$areanames{hy}->{3742675} = "Արծվաբերդ\/Բերդ\,\ Տավուշ";
$areanames{hy}->{3742676} = "Բերդ\,\ Տավուշ";
$areanames{hy}->{3742677} = "Բերդ\,\ Տավուշ";
$areanames{hy}->{3742678} = "Այգեպար\/Բերդ\,\ Տավուշ";
$areanames{hy}->{37426781} = "Բերդ\/Մոսեսգեղ\/Նավուր\/Նորաշեն\,\ Տավուշ";
$areanames{hy}->{3742679} = "Բերդ\,\ Տավուշ";
$areanames{hy}->{37426791} = "Նավուր\,\ Տավուշ";
$areanames{hy}->{37426794} = "Թովուզ\,\ Տավուշ";
$areanames{hy}->{37426796} = "Մոսեսգեղ\,\ Տավուշ";
$areanames{hy}->{37426797} = "Նորաշեն\,\ Տավուշ";
$areanames{hy}->{3742680} = "Դիլիջան\,\ Տավուշ";
$areanames{hy}->{3742682} = "Դիլիջան\,\ Տավուշ";
$areanames{hy}->{3742683} = "Դիլիջան\,\ Տավուշ";
$areanames{hy}->{3742684} = "Դիլիջան\/Հաղարծին\/Թեղուտ\,\ Տավուշ";
$areanames{hy}->{3742686} = "Դիլիջան\,\ Տավուշ";
$areanames{hy}->{37426881} = "Դիլիջան\/Հաղարծին\/Թեղուտ\,\ Տավուշ";
$areanames{hy}->{3742689} = "Դիլիջան\,\ Տավուշ";
$areanames{hy}->{37426895} = "Հաղարծին\,\ Տավուշ";
$areanames{hy}->{37426897} = "Թեղուտ\,\ Տավուշ";
$areanames{hy}->{374269} = "Վարդենիս\,\ Գեղարքունիք";
$areanames{hy}->{3742810} = "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742811} = "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742812} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742813} = "Եղեգնաձոր\/Մալիշկա\/Շատին\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742814} = "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742815} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428151} = "Խաչիկ\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742816} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742817} = "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742818} = "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428181} = "Եղեգնաձոր\/Մալիշկա\/Շատին\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428190} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428191} = "Արփի\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428192} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428193} = "Աղավնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428194} = "Արենի\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428195} = "Մալիշկա\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428196} = "Եղեգնաձոր\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428197} = "Ելփին\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428198} = "Ռինդ\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428199} = "Շատին\,\ Վայոց\ Ձոր";
$areanames{hy}->{374282} = "Վայք\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742830} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{3742832} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{3742833} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{37428351} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{3742836} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{3742837} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{37428375} = "Թասիկ\,\ Սյունիք";
$areanames{hy}->{3742838} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{3742839} = "Սիսիան\,\ Սյունիք";
$areanames{hy}->{37428396} = "Անգեղակոթ\,\ Սյունիք";
$areanames{hy}->{374284} = "Գորիս\,\ Սյունիք";
$areanames{hy}->{3742840} = "Գորիս\/Վերիշեն\,\ Սյունիք";
$areanames{hy}->{3742841} = "Գորիս\/Վերիշեն\,\ Սյունիք";
$areanames{hy}->{37428427} = "Վերիշեն\,\ Սյունիք";
$areanames{hy}->{3742847} = "Գորիս\/Վերիշեն\,\ Սյունիք";
$areanames{hy}->{3742848} = "Գորիս\/Վերիշեն\,\ Սյունիք";
$areanames{hy}->{37428491} = "Հարժիս\,\ Սյունիք";
$areanames{hy}->{37428494} = "Խնձորեսկ\,\ Սյունիք";
$areanames{hy}->{37428495} = "Շինուհայր\,\ Սյունիք";
$areanames{hy}->{37428499} = "Կոռնիձոր\,\ Սյունիք";
$areanames{hy}->{3742850} = "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք";
$areanames{hy}->{3742851} = "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք";
$areanames{hy}->{3742852} = "Կապան\,\ Սյունիք";
$areanames{hy}->{3742853} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{37428540} = "Կապան\,\ Սյունիք";
$areanames{hy}->{37428541} = "Կապան\,\ Սյունիք";
$areanames{hy}->{37428542} = "Կապան\,\ Սյունիք";
$areanames{hy}->{37428543} = "Կապան\,\ Սյունիք";
$areanames{hy}->{37428544} = "Կապան\,\ Սյունիք";
$areanames{hy}->{37428545} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{37428546} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{37428547} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{37428548} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{37428549} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{3742855} = "Կապան\,\ Սյունիք";
$areanames{hy}->{3742856} = "Կապան\,\ Սյունիք";
$areanames{hy}->{3742857} = "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք";
$areanames{hy}->{3742858} = "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք";
$areanames{hy}->{374285810} = "Կապան\,\ Սյունիք";
$areanames{hy}->{374285811} = "Կապան\,\ Սյունիք";
$areanames{hy}->{374285812} = "Կապան\,\ Սյունիք";
$areanames{hy}->{374285813} = "Կապան\,\ Սյունիք";
$areanames{hy}->{374285814} = "Կապան\,\ Սյունիք";
$areanames{hy}->{374285815} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{374285816} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{374285817} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{374285818} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{374285819} = "Քաջարան\,\ Սյունիք";
$areanames{hy}->{3742859} = "Կապան\,\ Սյունիք";
$areanames{hy}->{3742860} = "Մեղրի\/Ագարակ\,\ Սյունիք";
$areanames{hy}->{3742861} = "Մեղրի\/Ագարակ\,\ Սյունիք";
$areanames{hy}->{3742862} = "Ագարակ\,\ Սյունիք";
$areanames{hy}->{3742863} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{3742864} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{3742865} = "Ագարակ\/Շվանիձոր\,\ Սյունիք";
$areanames{hy}->{3742866} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{3742867} = "Մեղրի\/Ագարակ\,\ Սյունիք";
$areanames{hy}->{3742868} = "Մեղրի\/Ագարակ\,\ Սյունիք";
$areanames{hy}->{374286810} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286811} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286812} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286813} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286814} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286815} = "Ագարակ\/Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286816} = "Ագարակ\/Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286817} = "Ագարակ\/Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286818} = "Ագարակ\/Մեղրի\,\ Սյունիք";
$areanames{hy}->{374286819} = "Ագարակ\/Մեղրի\,\ Սյունիք";
$areanames{hy}->{3742869} = "Մեղրի\,\ Սյունիք";
$areanames{hy}->{37428695} = "Շվանիձոր\,\ Սյունիք";
$areanames{hy}->{374287} = "Ջերմուկ\,\ Վայոց\ Ձոր";
$areanames{hy}->{3742873} = "Ջերմուկ\/Գնդեվազ\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428781} = "Ջերմուկ\/Գնդեվազ\,\ Վայոց\ Ձոր";
$areanames{hy}->{37428794} = "Գնդեվազ\,\ Վայոց\ Ձոր";
$areanames{hy}->{374312} = "Գյումրի\,\ Շիրակ";
$areanames{hy}->{3743120} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{3743121} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{3743127} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431280} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431281} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431282} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431283} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431284} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{374312859} = "Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431286} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431287} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431288} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{37431289} = "Գյումրի\/Ախուրյան\,\ Շիրակ";
$areanames{hy}->{374322} = "Վանաձոր\,\ Լոռի";
$areanames{hy}->{3743220} = "Վանաձոր\/Գուգարք\,\ Լոռի";
$areanames{hy}->{3743221} = "Վանաձոր\/Գուգարք\,\ Լոռի";
$areanames{hy}->{3743228} = "Վանաձոր\/Գուգարք\,\ Լոռի";
$areanames{hy}->{37432293} = "Փամբակ\,\ Լոռի";
$areanames{hy}->{37432294} = "Լեռնապատ\,\ Լոռի";
$areanames{hy}->{37432295} = "Եղեգնուտ\,\ Լոռի";
$areanames{hy}->{37432296} = "Մարգահովիտ\,\ Լոռի";
$areanames{hy}->{37432297} = "Ձորագետ\,\ Լոռի";
$areanames{hy}->{37432298} = "Լերմոնտովո\,\ Լոռի";
$areanames{hy}->{37432299} = "Վահագնի\,\ Լոռի";
$areanames{hy}->{374470} = "Լեռնային\ Ղարաբաղ";
$areanames{hy}->{374471} = "Ստեփանակերտ";
$areanames{hy}->{374472} = "Լեռնային\ Ղարաբաղ";
$areanames{hy}->{374473} = "Լեռնային\ Ղարաբաղ";
$areanames{hy}->{374474} = "Մարտակերտ";
$areanames{hy}->{374475} = "Հադրութ";
$areanames{hy}->{374476} = "Ասկերան";
$areanames{hy}->{374477} = "Շուշի";
$areanames{hy}->{37447732} = "Բերձոր\/Քաշաթաղ";
$areanames{hy}->{374478} = "Մարտունի";
$areanames{hy}->{374479} = "Ստեփանակերտ";
$areanames{ru}->{37410} = "Ереван\/Джрвеж";
$areanames{ru}->{37411} = "Ереван";
$areanames{ru}->{37412} = "Ереван";
$areanames{ru}->{37415} = "Ереван";
$areanames{ru}->{3742220} = "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк";
$areanames{ru}->{3742221} = "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк";
$areanames{ru}->{3742222} = "Абовян\,\ Котайк";
$areanames{ru}->{3742223} = "Абовян\,\ Котайк";
$areanames{ru}->{3742224} = "Абовян\,\ Котайк";
$areanames{ru}->{3742225} = "Абовян\/Арзни\/Ариндж\/Гехашен\,\ Котайк";
$areanames{ru}->{3742226} = "Абовян\,\ Котайк";
$areanames{ru}->{3742227} = "Гарни\/Абовян\,\ Котайк";
$areanames{ru}->{3742228} = "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк";
$areanames{ru}->{37422281} = "Абовян\/Арзни\/Ариндж\/Гехашен\,\ Котайк";
$areanames{ru}->{37422290} = "Маяковский\,\ Котайк";
$areanames{ru}->{37422291} = "Балаовит\/Камарис\,\ Котайк";
$areanames{ru}->{37422292} = "Зовк\/Абовян\,\ Котайк";
$areanames{ru}->{37422293} = "Арамус\,\ Котайк";
$areanames{ru}->{37422294} = "Арзни\,\ Котайк";
$areanames{ru}->{37422295} = "Зовк\/Абовян\,\ Котайк";
$areanames{ru}->{37422296} = "Птхни\,\ Котайк";
$areanames{ru}->{37422297} = "Гехашен\,\ Котайк";
$areanames{ru}->{37422298} = "Ариндж\,\ Котайк";
$areanames{ru}->{37422299} = "Котайк";
$areanames{ru}->{3742230} = "Анкаван\/Раздан\/Цахкадзор\,\ Котайк";
$areanames{ru}->{3742231} = "Анкаван\/Раздан\/Цахкадзор\,\ Котайк";
$areanames{ru}->{3742232} = "Раздан\,\ Котайк";
$areanames{ru}->{3742233} = "Раздан\,\ Котайк";
$areanames{ru}->{3742234} = "Раздан\,\ Котайк";
$areanames{ru}->{3742235} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{3742236} = "Раздан\,\ Котайк";
$areanames{ru}->{37422370} = "Раздан\,\ Котайк";
$areanames{ru}->{37422371} = "Раздан\,\ Котайк";
$areanames{ru}->{37422372} = "Раздан\,\ Котайк";
$areanames{ru}->{37422373} = "Раздан\,\ Котайк";
$areanames{ru}->{37422374} = "Раздан\,\ Котайк";
$areanames{ru}->{37422375} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{37422376} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{37422377} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{37422378} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{37422379} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{3742238} = "Анкаван\/Раздан\/Цахкадзор\,\ Котайк";
$areanames{ru}->{374223810} = "Раздан\,\ Котайк";
$areanames{ru}->{374223811} = "Раздан\,\ Котайк";
$areanames{ru}->{374223812} = "Раздан\,\ Котайк";
$areanames{ru}->{374223813} = "Раздан\,\ Котайк";
$areanames{ru}->{374223814} = "Раздан\,\ Котайк";
$areanames{ru}->{374223815} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{374223816} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{374223817} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{374223818} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{374223819} = "Цахкадзор\,\ Котайк";
$areanames{ru}->{37422390} = "Раздан\,\ Котайк";
$areanames{ru}->{37422391} = "Лернанист\,\ Котайк";
$areanames{ru}->{37422392} = "Раздан\,\ Котайк";
$areanames{ru}->{37422393} = "Мехрадзор\,\ Котайк";
$areanames{ru}->{37422394} = "Пюник\,\ Котайк";
$areanames{ru}->{37422395} = "Раздан\,\ Котайк";
$areanames{ru}->{37422396} = "Раздан\,\ Котайк";
$areanames{ru}->{37422397} = "Солак\,\ Котайк";
$areanames{ru}->{37422398} = "Бжни\,\ Котайк";
$areanames{ru}->{37422399} = "Раздан\,\ Котайк";
$areanames{ru}->{3742240} = "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк";
$areanames{ru}->{3742241} = "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк";
$areanames{ru}->{3742242} = "Егвард\,\ Котайк";
$areanames{ru}->{3742243} = "Егвард\,\ Котайк";
$areanames{ru}->{3742244} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{3742245} = "Егвард\,\ Котайк";
$areanames{ru}->{37422452} = "Зовуни\,\ Котайк";
$areanames{ru}->{37422453} = "Прошян\,\ Котайк";
$areanames{ru}->{37422454} = "Аргел\,\ Котайк";
$areanames{ru}->{3742246} = "Егвард\,\ Котайк";
$areanames{ru}->{3742247} = "Егвард\/Нор\ Ачн\,\ Котайк";
$areanames{ru}->{3742248} = "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк";
$areanames{ru}->{374224810} = "Егвард\,\ Котайк";
$areanames{ru}->{374224811} = "Егвард\,\ Котайк";
$areanames{ru}->{374224812} = "Егвард\,\ Котайк";
$areanames{ru}->{374224813} = "Егвард\,\ Котайк";
$areanames{ru}->{374224814} = "Егвард\,\ Котайк";
$areanames{ru}->{374224815} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{374224816} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{374224817} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{374224818} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{374224819} = "Нор\ Ачн\,\ Котайк";
$areanames{ru}->{3742249} = "Егвард\,\ Котайк";
$areanames{ru}->{374226} = "Чаренцаван\,\ Котайк";
$areanames{ru}->{37422672} = "Арзакан\,\ Котайк";
$areanames{ru}->{37422675} = "Алапарс\/Варданаванк\,\ Котайк";
$areanames{ru}->{3742310} = "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир";
$areanames{ru}->{3742311} = "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир";
$areanames{ru}->{3742312} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{3742313} = "Звартноц\,\ Армавир";
$areanames{ru}->{3742314} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{3742315} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{3742316} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{3742317} = "Звартноц\,\ Армавир";
$areanames{ru}->{3742318} = "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир";
$areanames{ru}->{37423181} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{374231817} = "Звартноц\,\ Армавир";
$areanames{ru}->{374231818} = "Звартноц\,\ Армавир";
$areanames{ru}->{374231819} = "Звартноц\,\ Армавир";
$areanames{ru}->{37423190} = "Баграмян\,\ Армавир";
$areanames{ru}->{37423191} = "Ваче\,\ Армавир";
$areanames{ru}->{37423192} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{37423193} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{37423194} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{37423195} = "Норакерт\,\ Армавир";
$areanames{ru}->{37423196} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{37423197} = "Эчмиадзин\,\ Армавир";
$areanames{ru}->{37423198} = "Джрарат\,\ Армавир";
$areanames{ru}->{37423199} = "Хоронк\,\ Армавир";
$areanames{ru}->{3742320} = "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн";
$areanames{ru}->{3742321} = "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн";
$areanames{ru}->{3742322} = "Аштарак\,\ Арагацо́тн";
$areanames{ru}->{3742323} = "Аштарак\,\ Арагацо́тн";
$areanames{ru}->{3742324} = "Аштарак\/Бюракан\/Оганаван\,\ Арагацо́тн";
$areanames{ru}->{3742325} = "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн";
$areanames{ru}->{3742326} = "Аштарак\,\ Арагацо́тн";
$areanames{ru}->{3742327} = "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн";
$areanames{ru}->{3742328} = "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн";
$areanames{ru}->{37423281} = "Аштарак\/Бюракан\/Оганаван\,\ Арагацо́тн";
$areanames{ru}->{3742329} = "Аштарак\,\ Арагацо́тн";
$areanames{ru}->{37423290} = "Оганаван\,\ Арагацо́тн";
$areanames{ru}->{37423294} = "Бюракан\,\ Арагацо́тн";
$areanames{ru}->{3742330} = "Баграмян\/Лернагог\,\ Армавир";
$areanames{ru}->{3742331} = "Баграмян\/Лернагог\,\ Армавир";
$areanames{ru}->{3742332} = "Баграмян\,\ Армавир";
$areanames{ru}->{3742333} = "Баграмян\/Мясникян\,\ Армавир";
$areanames{ru}->{3742334} = "Баграмян\/Лернагог\,\ Армавир";
$areanames{ru}->{3742335} = "Баграмян\/Лернагог\,\ Армавир";
$areanames{ru}->{3742336} = "Баграмян\,\ Армавир";
$areanames{ru}->{3742337} = "Баграмян\,\ Армавир";
$areanames{ru}->{37423374} = "Мясникян\,\ Армавир";
$areanames{ru}->{37423375} = "Каракерт\,\ Армавир";
$areanames{ru}->{37423376} = "Даларик\,\ Армавир";
$areanames{ru}->{3742338} = "Баграмян\/Лернагог\,\ Армавир";
$areanames{ru}->{37423381} = "Баграмян\/Мясникян\,\ Армавир";
$areanames{ru}->{3742339} = "Баграмян\,\ Армавир";
$areanames{ru}->{374234} = "Арарат\/Веди\,\ Арарат";
$areanames{ru}->{3742340} = "Арарат\/Веди\/Воскетап\,\ Арарат";
$areanames{ru}->{3742341} = "Арарат\/Веди\/Воскетап\,\ Арарат";
$areanames{ru}->{3742345} = "Арарат\/Веди\/Воскетап\,\ Арарат";
$areanames{ru}->{374234510} = "Веди\,\ Арарат";
$areanames{ru}->{374234511} = "Веди\,\ Арарат";
$areanames{ru}->{374234512} = "Веди\,\ Арарат";
$areanames{ru}->{374234513} = "Веди\,\ Арарат";
$areanames{ru}->{374234514} = "Веди\,\ Арарат";
$areanames{ru}->{374234515} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{374234516} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{374234517} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{374234518} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{374234519} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423470} = "Веди\,\ Арарат";
$areanames{ru}->{37423471} = "Веди\,\ Арарат";
$areanames{ru}->{37423472} = "Веди\,\ Арарат";
$areanames{ru}->{37423473} = "Веди\,\ Арарат";
$areanames{ru}->{37423474} = "Веди\,\ Арарат";
$areanames{ru}->{37423475} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423476} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423477} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423478} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423479} = "Арарат\/Урцадзор\,\ Арарат";
$areanames{ru}->{37423481} = "Айгаван\,\ Арарат";
$areanames{ru}->{37423486} = "Урцадзор\,\ Арарат";
$areanames{ru}->{37423492} = "Мартиросян\,\ Арарат";
$areanames{ru}->{37423497} = "Покр\ Веди\,\ Арарат";
$areanames{ru}->{37423498} = "Таперакан\,\ Арарат";
$areanames{ru}->{3742350} = "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат";
$areanames{ru}->{3742351} = "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат";
$areanames{ru}->{3742352} = "Арташат\,\ Арарат";
$areanames{ru}->{3742353} = "Арташат\/Норашен\,\ Арарат";
$areanames{ru}->{3742354} = "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат";
$areanames{ru}->{3742355} = "Арташат\,\ Арарат";
$areanames{ru}->{3742356} = "Арташат\,\ Арарат";
$areanames{ru}->{3742357} = "Арташат\,\ Арарат";
$areanames{ru}->{3742358} = "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат";
$areanames{ru}->{37423581} = "Арташат\/Норашен\,\ Арарат";
$areanames{ru}->{3742360} = "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат";
$areanames{ru}->{3742361} = "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат";
$areanames{ru}->{3742362} = "Масис\,\ Арарат";
$areanames{ru}->{3742363} = "Айнтап\/Масис\,\ Арарат";
$areanames{ru}->{3742364} = "Масис\,\ Арарат";
$areanames{ru}->{3742365} = "Масис\,\ Арарат";
$areanames{ru}->{3742366} = "Масис\,\ Арарат";
$areanames{ru}->{3742367} = "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат";
$areanames{ru}->{3742368} = "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат";
$areanames{ru}->{37423681} = "Масис\,\ Арарат";
$areanames{ru}->{3742369} = "Масис\,\ Арарат";
$areanames{ru}->{37423699} = "Даштаван\,\ Арарат";
$areanames{ru}->{3742370} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{3742371} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{3742372} = "Армавир";
$areanames{ru}->{3742373} = "Мецамор\,\ Армавир";
$areanames{ru}->{3742374} = "Армавир";
$areanames{ru}->{37423747} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{37423748} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{37423749} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{3742375} = "Армавир";
$areanames{ru}->{3742376} = "Армавир";
$areanames{ru}->{3742377} = "Армавир\/Мргашат";
$areanames{ru}->{37423771} = "Армавир";
$areanames{ru}->{37423772} = "Мргашат\,\ Армавир";
$areanames{ru}->{37423779} = "Бамбакашат\,\ Армавир";
$areanames{ru}->{3742378} = "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир";
$areanames{ru}->{37423781} = "Армавир";
$areanames{ru}->{3742379} = "Армавир\/Налбандяна";
$areanames{ru}->{37423792} = "Налбандяна\,\ Армавир";
$areanames{ru}->{37423794} = "Маргара\,\ Армавир";
$areanames{ru}->{37423796} = "Тандзут\,\ Армавир";
$areanames{ru}->{37423798} = "Шенаван\,\ Армавир";
$areanames{ru}->{374238} = "Арарат\/Авшар\/Суренаван\/Ерасх";
$areanames{ru}->{3742420} = "Маралик\/Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742421} = "Маралик\/Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742422} = "Маралик\,\ Ширакский";
$areanames{ru}->{3742423} = "Маралик\,\ Ширакский";
$areanames{ru}->{37424231} = "Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742424} = "Маралик\,\ Ширакский";
$areanames{ru}->{3742425} = "Маралик\/Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742426} = "Маралик\,\ Ширакский";
$areanames{ru}->{3742427} = "Маралик\/Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742428} = "Маралик\/Сарнахбюр\,\ Ширакский";
$areanames{ru}->{3742429} = "Маралик\,\ Ширакский";
$areanames{ru}->{37424293} = "Ширакскийаван\,\ Ширакский";
$areanames{ru}->{37424297} = "Ани\ Каяран\,\ Ширакский";
$areanames{ru}->{37424300} = "Ахурян\/Арапи\/Камо\/Мусаелян\,\ Ширакский";
$areanames{ru}->{3742440} = "Артик\/Пемзашен\,\ Ширакский";
$areanames{ru}->{3742441} = "Артик\/Пемзашен\,\ Ширакский";
$areanames{ru}->{3742442} = "Артик\,\ Ширакский";
$areanames{ru}->{3742443} = "Артик\,\ Ширакский";
$areanames{ru}->{3742444} = "Артик\/Паник\,\ Ширакский";
$areanames{ru}->{3742445} = "Артик\,\ Ширакский";
$areanames{ru}->{3742446} = "Артик\,\ Ширакский";
$areanames{ru}->{3742447} = "Артик\/Пемзашен\,\ Ширакский";
$areanames{ru}->{3742448} = "Артик\/Пемзашен\,\ Ширакский";
$areanames{ru}->{37424481} = "Артик\/Паник\,\ Ширакский";
$areanames{ru}->{3742449} = "Артик\,\ Ширакский";
$areanames{ru}->{37424492} = "Паник\,\ Ширакский";
$areanames{ru}->{37424495} = "Аревшат\,\ Ширакский";
$areanames{ru}->{37424496} = "Мец\ Манташ\,\ Ширакский";
$areanames{ru}->{374245} = "Ашоцк\,\ Ширакский";
$areanames{ru}->{374246} = "Амасия\,\ Ширакский";
$areanames{ru}->{374249} = "Талин\,\ Арагацо́тн";
$areanames{ru}->{3742494} = "Талин\/Арагац\/Катнахбюр\/Мастара\,\ Арагацо́тн";
$areanames{ru}->{37424973} = "Катнахбюр\,\ Арагацо́тн";
$areanames{ru}->{37424981} = "Талин\/Арагац\/Катнахбюр\/Мастара\,\ Арагацо́тн";
$areanames{ru}->{3742499} = "Арагацаван\/Талин\,\ Арагацо́тн";
$areanames{ru}->{37424995} = "Арагац\,\ Арагацо́тн";
$areanames{ru}->{37424997} = "Мастара\,\ Арагацо́тн";
$areanames{ru}->{374252} = "Апаран\,\ Арагацо́тн";
$areanames{ru}->{3742524} = "Апаран\/Артаван\/Кучак\,\ Арагацо́тн";
$areanames{ru}->{37425281} = "Апаран\/Артаван\/Кучак\,\ Арагацо́тн";
$areanames{ru}->{37425291} = "Кучак\,\ Арагацо́тн";
$areanames{ru}->{37425295} = "Артаван\,\ Арагацо́тн";
$areanames{ru}->{3742530} = "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори";
$areanames{ru}->{3742531} = "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори";
$areanames{ru}->{3742532} = "Алаверди\,\ Лори";
$areanames{ru}->{3742533} = "Алаверди\,\ Лори";
$areanames{ru}->{3742534} = "Алаверди\,\ Лори";
$areanames{ru}->{3742535} = "Алаверди\,\ Лори";
$areanames{ru}->{37425352} = "Ахтала\,\ Лори";
$areanames{ru}->{37425353} = "Шнох\,\ Лори";
$areanames{ru}->{37425356} = "Чочкан\,\ Лори";
$areanames{ru}->{37425357} = "Туманян\,\ Лори";
$areanames{ru}->{3742536} = "Алаверди\,\ Лори";
$areanames{ru}->{3742537} = "Алаверди\/Ахтала\/Туманян\,\ Лори";
$areanames{ru}->{3742538} = "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори";
$areanames{ru}->{37425381} = "Алаверди\/Ахтала\/Туманян\,\ Лори";
$areanames{ru}->{3742539} = "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори";
$areanames{ru}->{374254} = "Ташир\,\ Лори";
$areanames{ru}->{3742543} = "Ташир\/Мецаван\,\ Лори";
$areanames{ru}->{37425481} = "Ташир\/Мецаван\,\ Лори";
$areanames{ru}->{3742549} = "Ташир\/Мецаван\,\ Лори";
$areanames{ru}->{37425494} = "Мецаван\,\ Лори";
$areanames{ru}->{374255} = "Спитак\,\ Лори";
$areanames{ru}->{3742560} = "Бовадзор\/Степанаван\,\ Лори";
$areanames{ru}->{3742561} = "Бовадзор\/Степанаван\,\ Лори";
$areanames{ru}->{3742562} = "Степанаван\,\ Лори";
$areanames{ru}->{3742563} = "Степанаван\,\ Лори";
$areanames{ru}->{3742564} = "Степанаван\,\ Лори";
$areanames{ru}->{3742565} = "Бовадзор\/Степанаван\,\ Лори";
$areanames{ru}->{3742566} = "Степанаван\,\ Лори";
$areanames{ru}->{3742567} = "Бовадзор\/Степанаван\,\ Лори";
$areanames{ru}->{3742568} = "Бовадзор\/Степанаван\,\ Лори";
$areanames{ru}->{37425681} = "Степанаван\,\ Лори";
$areanames{ru}->{3742569} = "Степанаван\,\ Лори";
$areanames{ru}->{37425691} = "Куртан\,\ Лори";
$areanames{ru}->{37425694} = "Агарак\,\ Лори";
$areanames{ru}->{37425695} = "Лежан\,\ Лори";
$areanames{ru}->{374257} = "Арагац\,\ Арагацо́тн";
$areanames{ru}->{3742570} = "Цахкаховит\,\ Арагацо́тн";
$areanames{ru}->{3742572} = "Цахкаховит\,\ Арагацо́тн";
$areanames{ru}->{3742573} = "Цахкаховит\,\ Арагацо́тн";
$areanames{ru}->{3742576} = "Цахкаховит\,\ Арагацо́тн";
$areanames{ru}->{37425781} = "Цахкаховит\,\ Арагацо́тн";
$areanames{ru}->{374261} = "Севан\,\ Гегаркуникский";
$areanames{ru}->{374262} = "Мартуни\,\ Гегаркуникский";
$areanames{ru}->{3742623} = "Мартуни\/Варденик\,\ Гегаркуникский";
$areanames{ru}->{37426252} = "Варденик\,\ Гегаркуникский";
$areanames{ru}->{37426253} = "Варденик\,\ Гегаркуникский";
$areanames{ru}->{37426272} = "Личк\,\ Гегаркуникский";
$areanames{ru}->{37426281} = "Мартуни\/Варденик\,\ Гегаркуникский";
$areanames{ru}->{37426299} = "Еранос\,\ Гегаркуникский";
$areanames{ru}->{3742630} = "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский";
$areanames{ru}->{3742631} = "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский";
$areanames{ru}->{3742632} = "Иджеван\/Айгеховит\/Ачаджур\,\ Тавушский";
$areanames{ru}->{3742633} = "Иджеван\,\ Тавушский";
$areanames{ru}->{3742634} = "Иджеван\,\ Тавушский";
$areanames{ru}->{3742635} = "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский";
$areanames{ru}->{3742636} = "Иджеван\,\ Тавушский";
$areanames{ru}->{3742637} = "Иджеван\,\ Тавушский";
$areanames{ru}->{37426374} = "Айгеховит\,\ Тавушский";
$areanames{ru}->{3742638} = "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский";
$areanames{ru}->{37426381} = "Иджеван\/Айгеховит\/Ачаджур\,\ Тавушский";
$areanames{ru}->{3742639} = "Иджеван\,\ Тавушский";
$areanames{ru}->{37426392} = "Ачаджур\,\ Тавушский";
$areanames{ru}->{37426397} = "Азатамут\,\ Тавушский";
$areanames{ru}->{374264} = "Гавар\,\ Гегаркуникский";
$areanames{ru}->{3742640} = "Гавар\/Сарухан\,\ Гегаркуникский";
$areanames{ru}->{3742641} = "Гавар\/Сарухан\,\ Гегаркуникский";
$areanames{ru}->{3742647} = "Гавар\/Сарухан\,\ Гегаркуникский";
$areanames{ru}->{3742648} = "Гавар\/Сарухан\,\ Гегаркуникский";
$areanames{ru}->{374265} = "Чамбарак\,\ Гегаркуникский";
$areanames{ru}->{3742654} = "Чамбарак\/Ваан\,\ Гегаркуникский";
$areanames{ru}->{37426581} = "Чамбарак\/Ваан\,\ Гегаркуникский";
$areanames{ru}->{37426596} = "Ваан\,\ Гегаркуникский";
$areanames{ru}->{3742660} = "Бердаван\/Кохб\/Ноемберян\,\ Тавушский";
$areanames{ru}->{3742661} = "Бердаван\/Кохб\/Ноемберян\,\ Тавушский";
$areanames{ru}->{3742662} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{3742663} = "Ноемберян\/Воскепар\/Кочи\/Кохб\,\ Тавушский";
$areanames{ru}->{3742664} = "Бердаван\/Кохб\/Ноемберян\,\ Тавушский";
$areanames{ru}->{3742665} = "Кохб\/Ноемберян\,\ Тавушский";
$areanames{ru}->{37426652} = "Кохб\,\ Тавушский";
$areanames{ru}->{37426653} = "Кохб\,\ Тавушский";
$areanames{ru}->{3742666} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{3742667} = "Бердаван\/Ноемберян\,\ Тавушский";
$areanames{ru}->{3742668} = "Бердаван\/Кохб\/Ноемберян\,\ Тавушский";
$areanames{ru}->{37426681} = "Ноемберян\/Воскепар\/Кочи\/Кохб\,\ Тавушский";
$areanames{ru}->{37426690} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{37426691} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{37426692} = "Арчис\,\ Тавушский";
$areanames{ru}->{37426693} = "Баганис\,\ Тавушский";
$areanames{ru}->{37426694} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{37426695} = "Зоракан\,\ Тавушский";
$areanames{ru}->{37426696} = "Воскепар\,\ Тавушский";
$areanames{ru}->{37426697} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{37426698} = "Ноемберян\,\ Тавушский";
$areanames{ru}->{37426699} = "Кочи\,\ Тавушский";
$areanames{ru}->{3742670} = "Айгепар\/Берд\,\ Тавушский";
$areanames{ru}->{3742671} = "Айгепар\/Берд\,\ Тавушский";
$areanames{ru}->{3742672} = "Берд\,\ Тавушский";
$areanames{ru}->{3742673} = "Берд\/Мосесгех\/Навур\/Норашен\,\ Тавушский";
$areanames{ru}->{3742674} = "Айгепар\/Берд\,\ Тавушский";
$areanames{ru}->{3742675} = "Арцваберд\/Берд\,\ Тавушский";
$areanames{ru}->{3742676} = "Берд\,\ Тавушский";
$areanames{ru}->{3742677} = "Берд\,\ Тавушский";
$areanames{ru}->{3742678} = "Айгепар\/Берд\,\ Тавушский";
$areanames{ru}->{37426781} = "Берд\/Мосесгех\/Навур\/Норашен\,\ Тавушский";
$areanames{ru}->{3742679} = "Берд\,\ Тавушский";
$areanames{ru}->{37426791} = "Навур\,\ Тавушский";
$areanames{ru}->{37426794} = "Товуз\,\ Тавушский";
$areanames{ru}->{37426796} = "Мосесгех\,\ Тавушский";
$areanames{ru}->{37426797} = "Норашен\,\ Тавушский";
$areanames{ru}->{3742680} = "Дилижан\,\ Тавушский";
$areanames{ru}->{3742682} = "Дилижан\,\ Тавушский";
$areanames{ru}->{3742683} = "Дилижан\,\ Тавушский";
$areanames{ru}->{3742684} = "Дилижан\/Агарцин\/Техут\,\ Тавушский";
$areanames{ru}->{3742686} = "Дилижан\,\ Тавушский";
$areanames{ru}->{37426881} = "Дилижан\/Агарцин\/Техут\,\ Тавушский";
$areanames{ru}->{3742689} = "Дилижан\,\ Тавушский";
$areanames{ru}->{37426895} = "Агарцин\,\ Тавушский";
$areanames{ru}->{37426897} = "Техут\,\ Тавушский";
$areanames{ru}->{374269} = "Варденис\,\ Гегаркуникский";
$areanames{ru}->{3742810} = "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742811} = "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742812} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742813} = "Ехегнадзор\/Малишка\/Шатин\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742814} = "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742815} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428151} = "Хачик\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742816} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742817} = "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742818} = "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428181} = "Ехегнадзор\/Малишка\/Шатин\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428190} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428191} = "Арпи\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428192} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428193} = "Агавнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428194} = "Арени\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428195} = "Малишка\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428196} = "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428197} = "Елпин\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428198} = "Ринд\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428199} = "Шатин\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{374282} = "Вайк\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742830} = "Сисиан\,\ Сюника";
$areanames{ru}->{3742832} = "Сисиан\,\ Сюника";
$areanames{ru}->{3742833} = "Сисиан\,\ Сюника";
$areanames{ru}->{37428351} = "Сисиан\,\ Сюника";
$areanames{ru}->{3742836} = "Сисиан\,\ Сюника";
$areanames{ru}->{3742837} = "Сисиан\,\ Сюника";
$areanames{ru}->{37428375} = "Тасик\,\ Сюника";
$areanames{ru}->{3742838} = "Сисиан\,\ Сюника";
$areanames{ru}->{3742839} = "Сисиан\,\ Сюника";
$areanames{ru}->{37428396} = "Ангехакот\,\ Сюника";
$areanames{ru}->{374284} = "Горис\,\ Сюника";
$areanames{ru}->{3742840} = "Горис\/Веришен\,\ Сюника";
$areanames{ru}->{3742841} = "Горис\/Веришен\,\ Сюника";
$areanames{ru}->{37428427} = "Веришен\,\ Сюника";
$areanames{ru}->{3742847} = "Горис\/Веришен\,\ Сюника";
$areanames{ru}->{3742848} = "Горис\/Веришен\,\ Сюника";
$areanames{ru}->{37428491} = "Аржис\,\ Сюника";
$areanames{ru}->{37428494} = "Хндзореск\,\ Сюника";
$areanames{ru}->{37428495} = "Шинуайр\,\ Сюника";
$areanames{ru}->{37428499} = "Корнидзор\,\ Сюника";
$areanames{ru}->{3742850} = "Давит\ Бек\/Каджаран\/Капан\,\ Сюника";
$areanames{ru}->{3742851} = "Давит\ Бек\/Каджаран\/Капан\,\ Сюника";
$areanames{ru}->{3742852} = "Капан\,\ Сюника";
$areanames{ru}->{3742853} = "Каджаран\,\ Сюника";
$areanames{ru}->{37428540} = "Капан\,\ Сюника";
$areanames{ru}->{37428541} = "Капан\,\ Сюника";
$areanames{ru}->{37428542} = "Капан\,\ Сюника";
$areanames{ru}->{37428543} = "Капан\,\ Сюника";
$areanames{ru}->{37428544} = "Капан\,\ Сюника";
$areanames{ru}->{37428545} = "Каджаран\,\ Сюника";
$areanames{ru}->{37428546} = "Каджаран\,\ Сюника";
$areanames{ru}->{37428547} = "Каджаран\,\ Сюника";
$areanames{ru}->{37428548} = "Каджаран\,\ Сюника";
$areanames{ru}->{37428549} = "Каджаран\,\ Сюника";
$areanames{ru}->{3742855} = "Капан\,\ Сюника";
$areanames{ru}->{3742856} = "Капан\,\ Сюника";
$areanames{ru}->{3742857} = "Давит\ Бек\/Каджаран\/Капан\,\ Сюника";
$areanames{ru}->{3742858} = "Давит\ Бек\/Каджаран\/Капан\,\ Сюника";
$areanames{ru}->{374285810} = "Капан\,\ Сюника";
$areanames{ru}->{374285811} = "Капан\,\ Сюника";
$areanames{ru}->{374285812} = "Капан\,\ Сюника";
$areanames{ru}->{374285813} = "Капан\,\ Сюника";
$areanames{ru}->{374285814} = "Капан\,\ Сюника";
$areanames{ru}->{374285815} = "Каджаран\,\ Сюника";
$areanames{ru}->{374285816} = "Каджаран\,\ Сюника";
$areanames{ru}->{374285817} = "Каджаран\,\ Сюника";
$areanames{ru}->{374285818} = "Каджаран\,\ Сюника";
$areanames{ru}->{374285819} = "Каджаран\,\ Сюника";
$areanames{ru}->{3742859} = "Капан\,\ Сюника";
$areanames{ru}->{3742860} = "Мегри\/Агарак\,\ Сюника";
$areanames{ru}->{3742861} = "Мегри\/Агарак\,\ Сюника";
$areanames{ru}->{3742862} = "Агарак\,\ Сюника";
$areanames{ru}->{3742863} = "Мегри\,\ Сюника";
$areanames{ru}->{3742864} = "Мегри\,\ Сюника";
$areanames{ru}->{3742865} = "Агарак\/Шванидзор\,\ Сюника";
$areanames{ru}->{3742866} = "Мегри\,\ Сюника";
$areanames{ru}->{3742867} = "Мегри\/Агарак\,\ Сюника";
$areanames{ru}->{3742868} = "Мегри\/Агарак\,\ Сюника";
$areanames{ru}->{374286810} = "Мегри\,\ Сюника";
$areanames{ru}->{374286811} = "Мегри\,\ Сюника";
$areanames{ru}->{374286812} = "Мегри\,\ Сюника";
$areanames{ru}->{374286813} = "Мегри\,\ Сюника";
$areanames{ru}->{374286814} = "Мегри\,\ Сюника";
$areanames{ru}->{374286815} = "Агарак\/Мегри\,\ Сюника";
$areanames{ru}->{374286816} = "Агарак\/Мегри\,\ Сюника";
$areanames{ru}->{374286817} = "Агарак\/Мегри\,\ Сюника";
$areanames{ru}->{374286818} = "Агарак\/Мегри\,\ Сюника";
$areanames{ru}->{374286819} = "Агарак\/Мегри\,\ Сюника";
$areanames{ru}->{3742869} = "Мегри\,\ Сюника";
$areanames{ru}->{37428695} = "Шванидзор\,\ Сюника";
$areanames{ru}->{374287} = "Джермук\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{3742873} = "Джермук\/Гндеваз\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428781} = "Джермук\/Гндеваз\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{37428794} = "Гндеваз\,\ ВАЙОЦДЗОРСКИЙ";
$areanames{ru}->{374312} = "Гюмри\,\ Ширакский";
$areanames{ru}->{3743120} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{3743121} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{3743127} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431280} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431281} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431282} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431283} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431284} = "Ахурян\,\ Ширакский";
$areanames{ru}->{374312859} = "Ахурян\,\ Ширакский";
$areanames{ru}->{37431286} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{37431287} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{37431288} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{37431289} = "Гюмри\/Ахурян\,\ Ширакский";
$areanames{ru}->{374322} = "Ванадзор\,\ Лори";
$areanames{ru}->{3743220} = "Ванадзор\/Гугарк\,\ Лори";
$areanames{ru}->{3743221} = "Ванадзор\/Гугарк\,\ Лори";
$areanames{ru}->{3743228} = "Ванадзор\/Гугарк\,\ Лори";
$areanames{ru}->{37432293} = "Памбак\,\ Лори";
$areanames{ru}->{37432294} = "Лернапат\,\ Лори";
$areanames{ru}->{37432295} = "Ехегнут\,\ Лори";
$areanames{ru}->{37432296} = "Маргаовит\,\ Лори";
$areanames{ru}->{37432297} = "Дзорагет\,\ Лори";
$areanames{ru}->{37432298} = "Лермонтово\,\ Лори";
$areanames{ru}->{37432299} = "Ваагни\,\ Лори";
$areanames{ru}->{374470} = "Нагорный\ Карабах";
$areanames{ru}->{374471} = "Степанакерт";
$areanames{ru}->{374472} = "Нагорный\ Карабах";
$areanames{ru}->{374473} = "Нагорный\ Карабах";
$areanames{ru}->{374474} = "Мартакерт";
$areanames{ru}->{374475} = "Гадрут";
$areanames{ru}->{374476} = "Аскеран";
$areanames{ru}->{374477} = "Шуши";
$areanames{ru}->{37447732} = "Бердзор\/Кашатах";
$areanames{ru}->{374478} = "Мартуни";
$areanames{ru}->{374479} = "Степанакерт";

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+374|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;